import WebAssemblyRunner from "@libmedia/cheap/webassembly/WebAssemblyRunner";

import * as logger from "@libmedia/common/util/logger";

import * as errorType from "@libmedia/avutil/error";

export default class Resampler {
    resampler;
    options;
    inputParameters;
    outputParameters;
    constructor(options) {
        this.options = options, this.resampler = new WebAssemblyRunner(this.options.resource);
    }
    async open(input, output) {
        this.inputParameters = input, this.outputParameters = output, await this.resampler.run(), 
        this.resampler.invoke("resample_set_input_parameters", input.sampleRate, input.channels, input.format, input.layout || 0), 
        this.resampler.invoke("resample_set_output_parameters", output.sampleRate, output.channels, output.format, output.layout || 0);
        let ret = this.resampler.invoke("resample_init");
        return ret < 0 ? (logger.error(`open resampler failed, ret: ${ret}`, "src/audioresample/Resampler.ts", 85), 
        errorType.INVALID_PARAMETERS) : 0;
    }
    resample(input, output, numberOfFrames) {
        return this.resampler.invoke("resample_process", input, output, numberOfFrames);
    }
    getOutputSampleCount(numberOfFrames) {
        return this.resampler.invoke("resample_nb_sample", numberOfFrames);
    }
    close() {
        this.resampler.invoke("resample_destroy"), this.resampler.destroy();
    }
    getInputPCMParameters() {
        return this.inputParameters;
    }
    getOutputPCMParameters() {
        return this.outputParameters;
    }
}
//# sourceMappingURL=Resampler.js.map